@@ -1,10 +1,8 @@
 """Tests for the models of the ``paypal_express_checkout`` app."""
 from django.test import TestCase
 
-from paypal_express_checkout.models import (
-    PaymentTransaction,
-    PaymentTransactionError,
-)
+from .. import models
+from . import factories
 
 
 class PaymentTransactionTestCase(TestCase):
@@ -13,7 +11,7 @@ class PaymentTransactionTestCase(TestCase):
 
     def test_instantiation(self):
         """Testing instantiation of the ``PaymentTransaction`` model."""
-        transaction = PaymentTransaction()
+        transaction = models.PaymentTransaction()
         self.assertTrue(transaction)
 
 
@@ -23,5 +21,14 @@ class PaymentTransactionErrorTestCase(TestCase):
 
     def test_instantiation(self):
         """Testing instantiation of the ``PaymentTransactionError`` model."""
-        error = PaymentTransactionError()
+        error = models.PaymentTransactionError()
         self.assertTrue(error)
+
+
+class PurchasedItemTestCase(TestCase):
+    """Tests for the ``PurchasedItem`` model."""
+    longMessage = True
+
+    def test_model(self):
+        instance = factories.PurchasedItemFactory()
+        self.assertTrue(instance.pk)
